==> ecological-engine-1.3.0-20121022.081415-76-sources.jar: org/gcube/dataanalysis/ecoengine/processing/factories/ClusterersFactory.java <==
package org.gcube.dataanalysis.ecoengine.processing.factories;

import java.util.ArrayList;
import java.util.List;

import org.gcube.dataanalysis.ecoengine.configuration.AlgorithmConfiguration;
import org.gcube.dataanalysis.ecoengine.datatypes.StatisticalType;
import org.gcube.dataanalysis.ecoengine.interfaces.Clusterer;

public class ClusterersFactory {

	public static Clusterer getClusterer(AlgorithmConfiguration config) throws Exception {
		Clusterer clus = (Clusterer) ProcessorsFactory.getProcessor(config, config.getConfigPath() + AlgorithmConfiguration.clusterersFile);
		return clus;
	}

	public static List<String> getAllClusterers(String configPath) throws Exception {
		List<String> cluss = ProcessorsFactory.getClasses(configPath + AlgorithmConfiguration.clusterersFile);
		return cluss;
	}

	public static List<StatisticalType> getClustererParameters(String configPath, String algorithmName) throws Exception {
		List<StatisticalType> inputs = ProcessorsFactory.getParameters(configPath + AlgorithmConfiguration.clusterersFile, algorithmName);
		return inputs;
	}

	public static String getDescription(String configPath, String algorithmName) throws Exception{
		String input = ProcessorsFactory.getDescription(configPath + AlgorithmConfiguration.clusterersFile, algorithmName);
		return input;
		}
	
	public static List<Clusterer> getClusterers(AlgorithmConfiguration config) throws Exception {
		List<Clusterer> clusterers = new ArrayList<Clusterer>();
		clusterers.add(getClusterer(config));
		return clusterers;
	}

}

==> ecological-engine-1.6.1-20130607.014119-64-sources.jar: org/gcube/dataanalysis/ecoengine/processing/factories/ClusterersFactory.java <==
package org.gcube.dataanalysis.ecoengine.processing.factories;

import java.util.ArrayList;
import java.util.List;

import org.gcube.dataanalysis.ecoengine.configuration.AlgorithmConfiguration;
import org.gcube.dataanalysis.ecoengine.datatypes.StatisticalType;
import org.gcube.dataanalysis.ecoengine.interfaces.Clusterer;
import org.gcube.dataanalysis.ecoengine.interfaces.ComputationalAgent;
import org.gcube.dataanalysis.ecoengine.interfaces.Generator;

public class ClusterersFactory {

	public static Clusterer getClusterer(AlgorithmConfiguration config) throws Exception {
		Clusterer clus = (Clusterer) ProcessorsFactory.getProcessor(config, config.getConfigPath() + AlgorithmConfiguration.clusterersFile);
		return clus;
	}

	public static List<String> getAllClusterers(String configPath) throws Exception {
		List<String> cluss = ProcessorsFactory.getClasses(configPath + AlgorithmConfiguration.clusterersFile);
		return cluss;
	}

	public static List<StatisticalType> getClustererParameters(String configPath, String algorithmName) throws Exception {
		List<StatisticalType> inputs = ProcessorsFactory.getParameters(configPath + AlgorithmConfiguration.clusterersFile, algorithmName);
		return inputs;
	}

	public static String getDescription(String configPath, String algorithmName) throws Exception{
		String input = ProcessorsFactory.getDescription(configPath + AlgorithmConfiguration.clusterersFile, algorithmName);
		return input;
		}
	
	public static List<ComputationalAgent> getClusterers(AlgorithmConfiguration config) throws Exception {
		List<ComputationalAgent> clusterers = new ArrayList<ComputationalAgent>();
		clusterers.add(getClusterer(config));
		ProcessorsFactory.addAgent2List(clusterers,GeneratorsFactory.getGenerator(config));
		return clusterers;
	}

}
